@@ -1,5 +1,5 @@
-mapping_type = {
-    "VARCHAR": "STRING",
+mapping_types = {
+    "STR": "STRING",
     "FLOAT": "FLOAT64",
     "INT": "INT64",
     "DATETIME": "TIMESTAMP"
